pub struct SqliteExecutor { /* private fields */ }Implementations
Sourceimpl SqliteExecutor
impl SqliteExecutor
pub async fn open(path: impl AsRef<Path>) -> Result<Self, SqliteError>
pub async fn open_with_options( path: impl AsRef<Path>, options: SqliteOptions, ) -> Result<Self, SqliteError>
pub async fn open_in_memory() -> Result<Self, SqliteError>
pub fn connection(&self) -> &Connection
Sourcepub async fn transaction<T, E, F>(
&self,
operation: F,
) -> Result<T, SqliteTransactionError<E>>
pub async fn transaction<T, E, F>( &self, operation: F, ) -> Result<T, SqliteTransactionError<E>>
Run an operation inside a transaction and always complete it.
The operation is committed on success and rolled back on error. If the calling task is cancelled while the operation is running, dropping the transaction schedules a rollback while retaining the connection gate.
Sourcepub async fn execute_schema(
&self,
sql: impl Into<String>,
) -> Result<(), SqliteError>
pub async fn execute_schema( &self, sql: impl Into<String>, ) -> Result<(), SqliteError>
Execute trusted schema SQL. Application values should use typed queries.