cast

Function cast 

pub fn cast<From, To>(
    expression: TypedExpression<From>,
    sql_type: &'static str,
) -> TypedExpression<To>
Cast a typed expression to a validated SQL type name.

When a driver has no native codec for the target type, first cast a bound value to its source SQL type and then cast that expression to the target.