pub trait MigrationLedger: Send + Sync {
type Error: Error + Send + Sync + 'static;
// Required method
fn applied_migrations<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<AppliedMigration>, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Reads the migration ledger without creating or changing database objects.
Serving processes use this boundary to prove that their required schema is already present while retaining a database role that has no DDL authority.
Required Associated Types
Required Methods
fn applied_migrations<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<Vec<AppliedMigration>, Self::Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".