pub struct Migrator<B> { /* private fields */ }Implementations
Sourceimpl<B: MigrationBackend> Migrator<B>
impl<B: MigrationBackend> Migrator<B>
pub async fn run( &self, migrations: impl IntoIterator<Item = Migration>, ) -> Result<MigrationReport, MigrationRunError<B::Error>>
Sourceimpl<B: MigrationLedger> Migrator<B>
impl<B: MigrationLedger> Migrator<B>
Sourcepub async fn verify_required(
&self,
migrations: impl IntoIterator<Item = Migration>,
) -> Result<(), MigrationRunError<B::Error>>
pub async fn verify_required( &self, migrations: impl IntoIterator<Item = Migration>, ) -> Result<(), MigrationRunError<B::Error>>
Verify that every supplied migration is present with its exact checksum, without locking or mutating the database.
Additional database migrations are admitted so an older serving process can run during an expand-compatible rolling upgrade. Callers remain responsible for deciding which schema versions are compatible.